chore: fix spelling and grammar (#35)

diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 4dca934..d8a009d 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -18,7 +18,7 @@
 
 # Contributing to Apache OpenWhisk
 
-Anyone can contribute to the OpenWhisk project and we welcome your contributions.
+Anyone can contribute to the OpenWhisk project, and we welcome your contributions.
 
 There are multiple ways to contribute: report bugs, improve the docs, and
 contribute code, but you must follow these prerequisites and guidelines:
@@ -47,7 +47,7 @@
 list to see if your issue has already been raised.
 
 A good bug report is one that make it easy for us to understand what you were trying to do and what went wrong.
-Provide as much context as possible so we can try to recreate the issue.
+Provide as much context as possible, so we can try to recreate the issue.
 
 ### Discussion
 
diff --git a/README.md b/README.md
index 9e49fd3..5a9c6db 100644
--- a/README.md
+++ b/README.md
@@ -15,7 +15,7 @@
 
 - `manifestPath`: Optional. A string specifying the location of the folder enclosing the manifest.yaml file. For example: `src/openwhisk`. If this parameter is not provided, it will default to the root of the github repo.
 
-- `envData`: Optional. A string with a json object providing any optional enviroment data specified by the manifest.yaml file. For example:
+- `envData`: Optional. A string with a json object providing any optional environment data specified by the manifest.yaml file. For example:
   ```
   "{
     "CLOUDANT_HOSTNAME": "some-hostname-bluemix.cloudant.com",
@@ -51,7 +51,7 @@
 
 With the repository created, you can now deploy from it.
 
-- For the most simple manifests, with no associated services you can run the command with a gitUrl parameter and a manifestPath parameter which tells wskdeploy which language you want from your project.
+- For the simplest manifests, with no associated services you can run the command with a gitUrl parameter, and a manifestPath parameter which tells wskdeploy which language you want from your project.
 
   ```
   wsk action invoke /whisk.system/deploy/wskdeploy
diff --git a/packages/actions/lib/common.js b/packages/actions/lib/common.js
index a7134f1..282115a 100644
--- a/packages/actions/lib/common.js
+++ b/packages/actions/lib/common.js
@@ -81,7 +81,7 @@
 }
 
 /**
- * recursive funciton to delete a folder, must first delete items inside.
+ * recursive function to delete a folder, must first delete items inside.
  * @param  {string} pathToDelete    inclusive path to folder to delete
  */
 function deleteFolder(pathToDelete) {
diff --git a/tests/src/test/scala/packages/deployWebTests.scala b/tests/src/test/scala/packages/deployWebTests.scala
index 0ffbed2..79fbbb7 100644
--- a/tests/src/test/scala/packages/deployWebTests.scala
+++ b/tests/src/test/scala/packages/deployWebTests.scala
@@ -111,8 +111,8 @@
       ), """"error": "Please enter the GitHub repo url in params"""", 400)
     }
 
-    // test to create a template with a nonexistant github repo provided
-    it should "return error if there is an nonexistant repo provided" in {
+    // test to create a template with a nonexistent github repo provided
+    it should "return error if there is an nonexistent repo provided" in {
       makePostCallWithExpectedResult(JsObject(
         "gitUrl" -> JsString(incorrectGithubRepo),
         "manifestPath" -> JsString(helloWorldPath),